@@ -2,7 +2,7 @@ package Geo::TCX;
 use strict;
 use warnings;
 
-our $VERSION = '1.02';
+our $VERSION = '1.03';
 
 =encoding utf-8
 
@@ -16,7 +16,9 @@ Geo::TCX - Parse and edit and TCX activity and course files from GPS training de
 
 =head1 DESCRIPTION
 
-C<Geo::TCX> enables the parsing and editing of TCX activity and course files. TCX files follow an XML schema developed by Garmin and common to its GPS sports devices. Among other methods, the module enables laps from an activity to be saved as individual *.tcx files, split into separate laps based on a given point, merged, or converted to courses to plan a future activity.
+C<Geo::TCX> enables the parsing and editing of TCX activity and course files, including those from FIT files. TCX files follow an XML schema developed by Garmin and common to its GPS sports devices. Among other methods, the module enables laps from an activity to be saved as individual *.tcx files, split into separate laps based on a given point, merged, or converted to courses to plan a future activity.
+
+FIT activity and course files are supported provided that L<Geo::FIT> is installed and that the C<fit2tcx.pl> script it provides appears on the user's path.
 
 The module supports files containing a single Activity or Course. Database files consisting of multiple activities or courses are not supported.
 
@@ -26,6 +28,8 @@ The documentation regarding TCX files in general uses the terms history and acti
 
 use Geo::TCX::Lap;
 use File::Basename;
+use File::Temp qw/ tempfile /;
+use IPC::System::Simple qw(system);
 use Cwd qw(cwd abs_path);
 use Carp qw(confess croak cluck);
 
@@ -41,8 +45,6 @@ loads and returns a new Geo::TCX instance using the I<$filename> supplied as fir
 or
   $o = Geo::TCX->new( \'...');
 
-C<work_dir> or C<wd> for short can be set to specify where to save any working files (such as with the save_laps() method). The module never actually L<chdir>'s, it just keeps track of where the user wants to save files (and not have to type filenames with path each time), hence it is always defined.
-
 The optional C<work_dir> (or C<wd> for short) specifies where to save any working files, such as with the save_laps() method. It can be supplied as a relative path or as an absolute path. If C<work_dir> is omitted, it is set based on the path of the I<$filename> supplied or the current working directory if the constructor is called with an XML string reference (see C<< set_wd() >> for more info).
 
 =back
@@ -60,9 +62,18 @@ sub new {
     if (ref( $first_arg ) eq 'SCALAR') {
         $txt = $$first_arg
     } else {
-        croak 'first argument must be a filename' unless -f $first_arg;
-        $txt = do { local(@ARGV, $/) = $first_arg; <> };
-        $o->set_filename($first_arg)
+        my $fname = $first_arg;
+        my $file_to_read = $first_arg;
+        croak 'first argument must be a filename' unless -f $fname;
+
+        if ($fname =~ /(?i:\.fit$)/) {
+            my ($fh, $tmp_fname) = tempfile();
+            _convert_fit_to_tcx( $fname, $tmp_fname );
+            $file_to_read = $tmp_fname;
+            $fname =~ s/(?i:.fit)$/.tcx/
+        }
+        $txt = do { local(@ARGV, $/) = $file_to_read; <> };
+        $o->set_filename($fname)
     }
 
     $txt =~ s,\r,,g;                               # if it's a windows file
@@ -627,6 +638,8 @@ sub _prep_tags {
 
 Sets/gets the filename. Returns the name of the file with the complete path.
 
+If the instance was created from a FIT file, the filename is set to the same name but with a C<.tcx> extension by default.
+
 =back
 
 =cut
@@ -841,6 +854,21 @@ sub _lap_number {
     return $lap_i
 }
 
+our $FitConvertPl;
+sub _convert_fit_to_tcx {
+    require Geo::FIT;
+    my ( $fname, $tmp_fname ) = @_;
+    if (!defined $FitConvertPl) {
+        for (split /:/, $ENV{PATH} ) {
+            $FitConvertPl  = $_ . '/fit2tcx.pl';
+            last if -f $FitConvertPl
+        }
+    }
+    my @args = ($fname, $tmp_fname);
+    system($^X, $FitConvertPl, @args);
+    return 1
+}
+
 =head1 EXAMPLES
 
 Coming soon.
@@ -855,7 +883,7 @@ Patrick Joly
 
 =head1 VERSION
 
-1.02
+1.03
 
 =head1 LICENSE AND COPYRIGHT
 
@@ -865,7 +893,7 @@ This module is free software; you can redistribute it and/or modify it under the
 
 =head1 SEE ALSO
 
-L<Geo::Gpx>
+L<Geo::Gpx>, L<Geo::FIT>.
 
 =head1 DISCLAIMER OF WARRANTY
 
